@@ -1,9 +1,10 @@
 from . import enums, helpers
 from ._helpers import as_callable
 from .config import MISSING, CachedConfig, CIConfig, Config
-from .env import EnvMapping, LowerEnvMapping
+from .enums import Env
 from .envconfig import EnvConfig
 from .exceptions import AlreadySet, InvalidCast, MissingName
+from .mapping import EnvMapping, LowerEnvMapping
 
 __all__ = [
     'as_callable',
@@ -13,6 +14,7 @@ __all__ = [
     'MISSING',
     'EnvMapping',
     'LowerEnvMapping',
+    'Env',
     'MissingName',
     'InvalidCast',
     'EnvConfig',
@@ -20,3 +22,6 @@ __all__ = [
     'enums',
     'helpers',
 ]
+
+
+__version__ = '1.7.0'
