@@ -2,10 +2,14 @@ import os
 import pathlib
 import typing
 
-from .env import EnvMapping, LowerEnvMapping
 from .exceptions import InvalidCast, MissingName
+from .mapping import EnvMapping, LowerEnvMapping
+
+
+class MISSING:
+    pass
+
 
-MISSING = object()
 StrOrPath = str | pathlib.Path
 AnyCallable = typing.Callable[[str], typing.Any]
 CastType = type | AnyCallable
@@ -59,9 +63,7 @@ class Config:
         default: typing.Any = MISSING,
     ) -> typing.Any:
         value = self._get_value(name, default)
-        if cast is None:
-            return value
-        return self._cast(name, value, cast)
+        return value if cast is None else self._cast(name, value, cast)
 
     @typing.overload
     def __call__(
